@@ -62,6 +62,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Local
 #include "configdialog.h"
 #include "contextmanager.h"
+#include "documentinfoprovider.h"
 #include "documentpanel.h"
 #include "fileopscontextmanageritem.h"
 #include "folderviewcontextmanageritem.h"
@@ -147,6 +148,7 @@ struct MainWindow::Private {
 	DocumentPanel* mDocumentPanel;
 	KUrlNavigator* mUrlNavigator;
 	ThumbnailView* mThumbnailView;
+	DocumentInfoProvider* mDocumentInfoProvider;
 	ThumbnailViewHelper* mThumbnailViewHelper;
 	ThumbnailViewPanel* mThumbnailViewPanel;
 	StartPage* mStartPage;
@@ -245,6 +247,9 @@ struct MainWindow::Private {
 		mUrlNavigator->setAutoFillBackground(true);
 		mUrlNavigator->setPalette(pal);
 
+		mDocumentInfoProvider = new DocumentInfoProvider(mDirModel);
+		mThumbnailView->setDocumentInfoProvider(mDocumentInfoProvider);
+
 		mThumbnailViewHelper = new ThumbnailViewHelper(mDirModel, mWindow->actionCollection());
 		mThumbnailView->setThumbnailViewHelper(mThumbnailViewHelper);
 
@@ -285,8 +290,9 @@ struct MainWindow::Private {
 		connect(mDocumentPanel, SIGNAL(nextImageRequested()),
 			mWindow, SLOT(goToNext()) );
 
-		ThumbnailBarView* bar = mDocumentPanel->thumbnailBar();
+		ThumbnailView* bar = mDocumentPanel->thumbnailBar();
 		bar->setModel(mDirModel);
+		bar->setDocumentInfoProvider(mDocumentInfoProvider);
 		bar->setThumbnailViewHelper(mThumbnailViewHelper);
 		bar->setSelectionModel(mThumbnailView->selectionModel());
 	}
@@ -476,6 +482,10 @@ struct MainWindow::Private {
 
 
 	void initDirModel() {
+		mDirModel->setKindFilter(
+			MimeTypeUtils::KIND_RASTER_IMAGE
+			| MimeTypeUtils::KIND_SVG_IMAGE
+			| MimeTypeUtils::KIND_VIDEO);
 		setDirModelShowDirs(true);
 
 		connect(mDirModel, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
@@ -491,14 +501,7 @@ struct MainWindow::Private {
 	}
 
 	void setDirModelShowDirs(bool showDirs) {
-		MimeTypeUtils::Kinds kinds =
-			MimeTypeUtils::KIND_RASTER_IMAGE
-			| MimeTypeUtils::KIND_SVG_IMAGE
-			| MimeTypeUtils::KIND_VIDEO;
-		if (showDirs) {
-			kinds |= MimeTypeUtils::KIND_DIR | MimeTypeUtils::KIND_ARCHIVE;
-		}
-		mDirModel->setKindFilter(kinds);
+		mDirModel->adjustKindFilter(MimeTypeUtils::KIND_DIR | MimeTypeUtils::KIND_ARCHIVE, showDirs);
 	}
 
 	QModelIndex currentIndex() const {
@@ -544,7 +547,7 @@ struct MainWindow::Private {
 		mContextManager->setCurrentDirUrl(url);
 		mThumbnailViewHelper->setCurrentDirUrl(url);
 		if (url.isValid()) {
-			mUrlNavigator->setUrl(url);
+			mUrlNavigator->setLocationUrl(url);
 			mGoUpAction->setEnabled(url.path() != "/");
 			mGvCore->addUrlToRecentFolders(url);
 		} else {
@@ -559,10 +562,9 @@ struct MainWindow::Private {
 
 		ThumbnailBarView* view = mFullScreenContent->thumbnailBar();
 		view->setModel(mDirModel);
+		view->setDocumentInfoProvider(mDocumentInfoProvider);
 		view->setThumbnailViewHelper(mThumbnailViewHelper);
 		view->setSelectionModel(mThumbnailView->selectionModel());
-
-		mFullScreenBar->adjustSize();
 	}
 
 
@@ -660,7 +662,9 @@ struct MainWindow::Private {
 		}
 		QModelIndex index = mDirModel->indexForUrl(mUrlToSelect);
 		if (index.isValid()) {
-			mThumbnailView->setCurrentIndex(index);
+			if (index != mThumbnailView->currentIndex()) { // Avoid infinite recursion. Bug #243091
+				mThumbnailView->setCurrentIndex(index);
+			}
 			mThumbnailView->scrollTo(index, QAbstractItemView::PositionAtCenter);
 			mUrlToSelect = KUrl();
 		}
@@ -771,8 +775,6 @@ d(new MainWindow::Private)
 
 	createGUI();
 	loadConfig();
-	connect(DocumentFactory::instance(), SIGNAL(documentChanged(const KUrl&)),
-		SLOT(generateThumbnailForUrl(const KUrl&)) );
 
 	connect(DocumentFactory::instance(), SIGNAL(modifiedDocumentListChanged()),
 		SLOT(slotModifiedDocumentListChanged()) );
@@ -995,8 +997,8 @@ void MainWindow::openDirUrl(const KUrl& url) {
 		// If currentPath is      "/home/user/photos/2008/event"
 		// and wantedPath is      "/home/user/photos"
 		// pathToSelect should be "/home/user/photos/2008"
-		const QString currentPath = QDir::cleanPath(currentUrl.path(KUrl::RemoveTrailingSlash));
-		const QString wantedPath  = QDir::cleanPath(url.path(KUrl::RemoveTrailingSlash));
+		const QString currentPath = QDir::cleanPath(currentUrl.toLocalFile(KUrl::RemoveTrailingSlash));
+		const QString wantedPath  = QDir::cleanPath(url.toLocalFile(KUrl::RemoveTrailingSlash));
 		const QChar separator('/');
 		const int slashCount = wantedPath.count(separator);
 		const QString pathToSelect = currentPath.section(separator, 0, slashCount + 1);
@@ -1151,7 +1153,6 @@ void MainWindow::goToNext() {
 
 
 void MainWindow::goToUrl(const KUrl& url) {
-	kDebug() << url;
 	if (d->mCurrentPageId == ViewPageId) {
 		openDocumentUrl(url);
 	}
@@ -1331,16 +1332,6 @@ void MainWindow::updateSlideShowAction() {
 }
 
 
-
-void MainWindow::generateThumbnailForUrl(const KUrl& url) {
-	QModelIndex index = d->mDirModel->indexForUrl(url);
-	if (!index.isValid()) {
-		return;
-	}
-	d->mThumbnailView->generateThumbnailForIndex(index);
-}
-
-
 bool MainWindow::queryClose() {
 	saveConfig();
 	d->saveSideBarConfig();
@@ -1405,6 +1396,8 @@ void MainWindow::toggleMenuBar() {
 
 void MainWindow::loadConfig() {
 	d->mDirModel->setBlackListedExtensions(GwenviewConfig::blackListedExtensions());
+	MimeTypeUtils::Kinds kind = d->mDirModel->kindFilter();
+	d->mDirModel->adjustKindFilter(MimeTypeUtils::KIND_VIDEO, GwenviewConfig::listVideos());
 
 	d->mDocumentPanel->loadConfig();
 	d->mThumbnailViewPanel->loadConfig();
